
## CATO-CLI - mutation.policy.appTenantRestriction.updateSection:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateSection) for documentation on this operation.

### Usage for mutation.policy.appTenantRestriction.updateSection:

`catocli mutation policy appTenantRestriction updateSection -h`

`catocli mutation policy appTenantRestriction updateSection <json>`

`catocli mutation policy appTenantRestriction updateSection "$(cat < updateSection.json)"`

`catocli mutation policy appTenantRestriction updateSection '{"appTenantRestrictionPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}, "policyUpdateSectionInput": {"id": {"id": "ID"}, "policyUpdateSectionInfoInput": {"name": {"name": "String"}}}}'`

#### Operation Arguments for mutation.policy.appTenantRestriction.updateSection ####
`accountId` [ID] - (required) N/A 
`appTenantRestrictionPolicyMutationInput` [AppTenantRestrictionPolicyMutationInput] - (optional) N/A 
`policyUpdateSectionInput` [PolicyUpdateSectionInput] - (required) N/A 
